{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "feature-switch-watcher.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "feature-switch-watcher.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create a default fully qualified component name within the app.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "feature-switch-watcher.componentName" -}}
{{- printf "%s-%s" (include "feature-switch-watcher.fullname" .context) .name | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "feature-switch-watcher.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Common labels
*/}}
{{- define "feature-switch-watcher.labels" -}}
helm.sh/chart: {{ include "feature-switch-watcher.chart" . }}
{{ include "feature-switch-watcher.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
vmware/version: {{ .Values.global.vmwareVersion | quote }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "feature-switch-watcher.selectorLabels" -}}
app.kubernetes.io/name: {{ include "feature-switch-watcher.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end -}}

{{/*
Create the reference to a docker image
*/}}
{{- define "feature-switch-watcher.imageReference" -}}
{{- $imageDigestValue := index .Values.global .Values.images.watcher.digestName -}}
{{- if $imageDigestValue -}}
image: "{{ .Values.global.image.registry | default .Values.images.watcher.registry }}/{{ .Values.images.watcher.repository }}@{{ $imageDigestValue }}"
{{- else -}}
image: "{{ .Values.global.image.registry | default .Values.images.watcher.registry }}/{{ .Values.images.watcher.repository }}:{{ .Values.global.image.tag | default .Values.images.watcher.tag }}"
{{- end }}
imagePullPolicy: {{ .Values.images.watcher.pullPolicy | quote }}
{{- end -}}

{{/*
Get the name of the service account used by this deployment

NOTE: This helm chart is typically deployed as dependency of a parent chart. This parent
may need the ability to tell us the service account to use. By default, we come up with a
name ourselves, but if multiple helm charts with a dependency on this chart are deployed
in the same namespace, we need to make sure these default names don't collide. That's why
we have a slightly complicated if-defined-otherwise-default logic here
*/}}
{{- define "feature-switch-watcher.serviceAccountName" -}}
{{- if .Values.serviceAccount.name -}}
{{- .Values.serviceAccount.name -}}
{{- else -}}
{{- include "feature-switch-watcher.componentName" (dict "context" . "name" "serviceaccount") -}}
{{- end -}}
{{- end -}}
